@@ -270,6 +270,8 @@ def create_dataset(data, look_back=1):
     return np.array(dataX), np.array(dataY)
 
 
+#######################################################################################################################
+
 # Scale dataset
 class Scaler:
     def __init__(self, data, columns):
@@ -303,7 +305,7 @@ class Scaler:
             ... +-----------+-----------+-----------+-----------+-----------+-----------+
             >>> # Load scaler class
             >>> scaler = Scaler(data=data, columns=['X1', 'X2'])
-            >>> # Scaler our dataset with MinMax method
+            >>> # Scale our dataset with MinMax method
             >>> scaled_df = scaler.MinMax()
             >>> print(scaled_df)
             ... +-----------+-----------+-----------+-----------+-----------+-----------+
